////////////////////////////////////////////////////////////////////////////
////                             LCD.C                                  ////
////                 Driver for common LCD modules                      ////
////                                                                    ////
////  lcd_init()   Must be called before any other function.            ////
////                                                                    ////
////  lcd_putc(c)  Will display c on the next position of the LCD.      ////
////                     The following have special meaning:            ////
////                      \f  Clear display                             ////
////                      \n  Go to start of second line                ////
////                      \b  Move back one position                    ////
////                                                                    ////
////  lcd_gotoxy(x,y) Set write position on LCD (upper left is 1,1)     ////
////                                                                    ////
////  lcd_getc(x,y)   Returns character at position x,y on LCD          ////
////                                                                    ////
////////////////////////////////////////////////////////////////////////////
////        (C) Copyright 1996,1997 Custom Computer Services            ////
//// This source code may only be used by licensed users of the CCS C   ////
//// compiler.  This source code may only be distributed to other       ////
//// licensed users of the CCS C compiler.  No other use, reproduction  ////
//// or distribution is permitted without written permission.           ////
//// Derivative programs created using this software in object code     ////
//// form are not restricted in any way.                                ////
////////////////////////////////////////////////////////////////////////////
// Krzysztof Pawsiuk (2002)- Procedura obslugiwyswietlacza LCD zostala ////
// stworzona na bazie procedury udostepnianej wraz z kompilatorem.		////
// Procedura zostala w znacznym stopniu przebudowana, najwazniejsza 	////
// zmiana umozliwia dowolne przypisanie pinow sterujacych wyswietlaczem ////
// poszczegolne linie danych lub sterujace moga pochodzic z roznych     ////
// portow.																////
////////////////////////////////////////////////////////////////////////////

//*************************************************************************//
//	Deklaracja parametrow startowych niezbednych do sterowania			   //
//  wyswietlaczem									   					   //
//*************************************************************************//
#ifndef lcd									//definicja pinow
   //#define   lcd_rw        porta_2		//jesli ma byc rowniez odczyt
   //#define   lcd_tris_rw   trisa_2		//do nalezy podac pin RW
   #define   lcd_en        porta_7			//pin EN
   #define   lcd_tris_en   trisa_7			//tris EN
   #define   lcd_rs        porta_6			//pin RS
   #define   lcd_tris_rs   trisa_6			//tris RS
   #define   lcd_d7        porta_3			//pin D7
   #define   lcd_tris_d7   trisa_3			//tris D7
   #define   lcd_d6        porta_2			//pin D6
   #define   lcd_tris_d6   trisa_2			//tris D6
   #define   lcd_d5        porta_1			//pin D5
   #define   lcd_tris_d5   trisa_1			//tris D5
   #define   lcd_d4        porta_0			//pin D4
   #define   lcd_tris_d4   trisa_0			//tris D4
#endif

#define cursorOn	17						//wartosc wlaczajaca kursor
#define CursorOff	18						//wartosc wylaczajaca kursor
#define lcd_type 2           				// 0=5x7, 2 linie
#define lcd_line_two 0x40    				// LCD RAM adres drugiej lini
//*************************************************************************//

//male litery, wszystkie polskie znaki maja wartosci wieksze od 139
//dlatego do wykrycia czy to jest polski znak sprawdzane jest czy jest
//od 139
#define _a			0//0xB9			//
#define _e			1//0xEA			//
#define _n			2//0xF1			//
#define _z			3//0xBF			//
#define _c			4//0xE6			//
#define _s			5//0x9C			//
//#define _x			0x9F			//
#define _o			6//0xF3			//
#define _l			7//0xB3			//

/////////////////////////////////////////////////////////////////////////
byte const LcdDefLow[8]={//0x00,0x00,0x0E,0x01,0x0F,0x11,0x0F,0x02,	//
					   0x06,0x09,0x09,0x06,0x00,0x00,0x00,0x00};	//stopien
//					   0x00,0x00,0x0E,0x11,0x1F,0x10,0x0E,0x02,     //
//					   0x01,0x02,0x16,0x19,0x11,0x11,0x11,0x00,     //
//					   0x00,0x04,0x1F,0x02,0x04,0x08,0x1F,0x00,     //
//					   0x02,0x04,0x0E,0x10,0x10,0x11,0x0E,0x00,     //
//					   0x02,0x04,0x0E,0x10,0x0E,0x01,0x1E,0x00,	    //
//					   0x02,0x04,0x0E,0x11,0x11,0x11,0x0E,0x00,	    //
//					   0x0C,0x04,0x06,0x0C,0x04,0x04,0x0E,0x00};	//
////////////////////////////////////////////////////////////////////////////



#ifdef lcd_rw
//*******************************************************************************//
// Odczyt bajtu z LCD- mozliwe tylko wtedy, gdy zdefiniowany zostal pin lcd_rw   //
// czyli komunikacja dwustronna													 //
//*******************************************************************************//
byte lcd_read_byte()
{byte low,high;
 //set_tris_b(LCD_READ);
 lcd_tris_d7=1;							//piny danych jako wejscia
 lcd_tris_d6=1;
 lcd_tris_d5=1;
 lcd_tris_d4=1;
 lcd_rw = 1;							//tryb odczytu
 delay_cycles(1);
 lcd_en = 1;							//LCD wystawia starsza tetrade
 delay_cycles(1);
 high=0;              					//odzczytuje stany wszystkich wejsc danych
 if(lcd_d4) high+=1;          			//najpierw starsza tetrada do high
 if(lcd_d5) high+=2;
 if(lcd_d6) high+=4;
 if(lcd_d7) high+=8;
 lcd_en = 0;
 delay_cycles(1);
 lcd_en = 1;							//LCD wystawia mlodsza tetrade
 delay_us(1);
 low=0;
 if(lcd_d4) low+=1;   					//odczytaj mlodsza tetrade i zapisz do low
 if(lcd_d5) low+=2;
 if(lcd_d6) low+=4;
 if(lcd_d7) low+=8;
 lcd_en = 0;
 lcd_tris_d7=0;							//piny danych jako wyjscia
 lcd_tris_d6=0;
 lcd_tris_d5=0;
 lcd_tris_d4=0;
 return( (high<<4) | low);				//zwroc odczytany bajt
}
#endif
//***********************************************************************************//

//***********************************************************************************//
//  Wysyla polowe bajtu do wyswietlacza												 //
//***********************************************************************************//
void lcd_send_nibble( byte n )
{
   lcd_d4=bit_test(n,0);					//kopiuj 4bity bajtu na odpowiednie piny
   lcd_d5=bit_test(n,1);					//wyswietlacza
   lcd_d6=bit_test(n,2);
   lcd_d7=bit_test(n,3);
   delay_cycles(1);
   lcd_en = 1;								//zapisz do LCD
   delay_us(2);
   lcd_en = 0;
}
//************************************************************************************//

//************************************************************************************//
// Wysyla jeden bajt do LCD															  //
//************************************************************************************//
void lcd_send_byte( byte address, byte n )
{
  lcd_rs = 0;
#ifdef lcd_rw								//jesli komunikacja dwustronna, to
      while ( bit_test(lcd_read_byte(),7) );//czekaj az wyswietlacz bedzie gotowy
#else										//jesli komunikacja jednostronna
      delay_us(40);     					//to odczekaj 40us
      lcd_rs = address;						//jesli address=1. to zapis bajtu jako znak
      delay_cycles(1);						//jesli=0, to zapis jako instrukcja
#ifdef lcd_rw                 				//jesli komunikacja dwustronna, to przelacz
      lcd_rw = 0;							// na zapis
#endif
      delay_cycles(1);
      lcd_en = 0;
      lcd_send_nibble(n >> 4);				//wyslij starsza tetrade bajtu do wyswietlacza
      lcd_send_nibble(n & 0xf);				// i mlodsza
}
//************************************************************************************//

//**************************************************************************************//
//Inicjalizacja wyswietlacza, do pracy 4bitowej  										//
//**************************************************************************************//
void lcd_init()
{byte i;
  lcd_d7=0;									//wpisz 0 na wszystkie piny danych
  lcd_d6=0;
  lcd_d5=0;
  lcd_d4=0;                     			//ustaw piny danych jako wyjscia
  lcd_tris_d7=0;
  lcd_tris_d6=0;
  lcd_tris_d5=0;
  lcd_tris_d4=0;
  lcd_rs = 0;								//zeruj pin RS i ustaw jako wyjscie
  lcd_tris_rs=0;                            //zeruj pin EN i ustaw jako wyjscie
  lcd_en = 0;
  lcd_tris_en=0;
#ifdef lcd_rw								//jesli zdefiniowana komunikacja dwustronna,
    lcd_rw = 0;								//to zeruj pin RW i ustaw jako wyjscie
    lcd_tris_rw=0;
#endif
    delay_ms(15);                           //czekaj na start lcd
    for(i=1;i<=3;++i) {
       lcd_send_nibble(3);					//ustaw tryb 4bitowy
       delay_ms(5);
    }
   lcd_send_nibble(2);						//wyswietlacz dwu liniowy
   lcd_send_byte(0,0x20 | (lcd_type << 2)); // bez kursora
   lcd_send_byte(0,0xc);
   lcd_send_byte(0,1);
   delay_ms(2);
   lcd_send_byte(0,6);
}
//*************************************************************************************//

//******************************************************************************//
// ustawia kursor na pozycji xy													//
//******************************************************************************//
void lcd_gotoxy( byte y, byte x)
{byte address;
 if(y!=1)
     address=lcd_line_two;
 else
   address=0;
   address+=x-1;
   lcd_send_byte(0,0x80|address);
}
//********************************************************************************//

//********************************************************************************//
//    wyswietla znaki na wyswietlaczu											  //
//********************************************************************************//
void lcd_putc(char f)
{
switch (f)
   {
   case '\r'     : lcd_send_byte(0,1);					//kasuj LCD
                   delay_ms(2);
                   break;
   case '\n'     : lcd_gotoxy(2,1);            break;	//nowa linia LCD
   case cursorOn : lcd_send_byte(0,0b00001110);break;	//wlacz kursor
   case cursorOff: lcd_send_byte(0,0b00001100);break;	//wylacz kursor
   default       : lcd_send_byte(1,f);         break;	//wyswietl znak
   }
}
//*******************************************************************************//

//*******************************************************************************//
// Wyswietla bajt jako dwie cyfry BCD											 //
//*******************************************************************************//
void lcd_putbcd( int cd)
  {
  lcd_send_byte(1, (cd/16)+'0' );
  lcd_send_byte(1, (cd%16)+'0' );
  }
//*******************************************************************************//

//*******************************************************************************//
// Wyswietla bajt dziesietnie , max. wartosc= 99								 //
//*******************************************************************************//
Void lcd_putdec(int de)
{
  lcd_send_byte(1, (de/10)+'0' );
  lcd_send_byte(1, (de%10)+'0' );
}
//*******************************************************************************//

//*******************************************************************************//
// Kasuje podana linie wiswietlacza												 //
//*******************************************************************************//
Lcd_clear(int linia)
{int i;

    if(linia==1)	{lcd_gotoxy(2,1);		//jesli piewrsza linia, to wpisz spacje
     				for(i=0;i<=19;i++) lcd_send_byte(1,0x20);
     				}
    if(linia==2)	{lcd_gotoxy(2,1);      //jesli druga linia, to wpisz spacje
	     				for(i=0;i<=19;i++) lcd_send_byte(1,0x20);
     				}
  }
//******************************************************************************//

//******************************************************************************//
//laduje do pamieci LCD definiowane znaki, tym przypadkuzapisywany jest tylko	//
//znak Stopien celcjusza, pod adresem ) w pamieci LCD							//
//******************************************************************************//
void lcd_znaki()
{
int licz;
      lcd_send_byte(0,0x40);  				//ustawienie adresu pamieci lcd na zero
      for(licz=0;licz<8;licz++)
         lcd_send_byte(1,lcdDefLow[licz]);  //wysyla dane do LCD odczytane z tablicy
 }
//*******************************************************************************//
