#nolist
/*        LIST
; P12F675.INC  Standard Header File, Version 1.04    Microchip Technology, Inc.
        NOLIST

; This header file defines configurations, registers, and other useful bits of
; information for the PIC12F675 microcontroller.  These names are taken to match 
; the data sheets as closely as possible.  

; Note that the processor must be selected before this file is 
; included.  The processor may be selected the following ways:

;       1. Command line switch:
;               C:\ MPASM MYFILE.ASM /PIC12F675
;       2. LIST directive in the source file
;               LIST   P=PIC12F675
;       3. Processor Type entry in the MPASM full-screen interface

;==========================================================================
;
;       Revision History
;
;==========================================================================
;1.04	07/01/02 Updated configuration bit names
;1.03	05/10/02 Corrected ADCON0 register, added IOC register
;1.02	02/28/02 Updated per datasheet
;1.01	01/31/02 Updated per datasheet
;1.00   08/24/01 Original

;==========================================================================
;
;       Verify Processor
;
;==========================================================================

        IFNDEF __12F675
           MESSG "Processor-header file mismatch.  Verify selected processor."
        ENDIF

;==========================================================================
;
;       Register Definitions
;
;==========================================================================

W                            EQU     H'0000'
F                            EQU     H'0001'
*/
//;----- Register Files------------------------------------------------------

#byte		INDF           =      	 0x000
#byte		TMR0           =      	 0x001
#byte		PCL            =      	 0x002
#byte		STATUS         =      	 0x003
#byte		FSR            =      	 0x004
#byte		GPIO           =      	 0x005

#byte		PCLATH         =      	 0x00A
#byte		INTCON         =      	 0x00B
#byte		PIR1		   =      	 0x00C

#byte		TMR1L		   =      	 0x00E		
#byte		TMR1H		   =      	 0x00F		
#byte		T1CON		   =	     0x010		
		
#byte		CMCON		   =	     0x019		

#byte		ADRESH		   =	     0x01E		
#byte		ADCON0		   =	     0x01F		


#byte		OPTION_REG     =         0x081

#byte		TRISIO		   =	     0x085

#byte		PIE1		   =	     0x08C

#byte		PCON		   =	     0x08E

#byte		OSCCAL		   =	     0x090

#byte		WPU			   =     	 0x095
#byte		IOC			   =     	 0x096
#byte		IOCB		   =	     0x096

#byte		VRCON		   =	     0x099
#byte		EEDATA		   =	     0x09A	
#byte		EEADR		   =	     0x09B	
#byte		EECON1		   =	     0x09C
#byte		EECON2		   =	     0x09D
#byte		ADRESL		   =	     0x09E		
#byte		ANSEL		   =	     0x09F

#bit		gpio_0		   =		 0x05.0
#bit		gpio_1		   =		 0x05.1
#bit		gpio_2		   =		 0x05.2
#bit		gpio_3		   =		 0x05.3
#bit		gpio_4		   =		 0x05.4
#bit		gpio_5		   =		 0x05.5
#bit		trisio_0	   =		 0x085.0
#bit		trisio_1	   =		 0x085.1
#bit		trisio_2	   =		 0x085.2
#bit		trisio_3	   =		 0x085.3
#bit		trisio_4	   =		 0x085.4
#bit		trisio_5	   =		 0x085.5
								
								

//;----- STATUS Bits --------------------------------------------------------

#define		IRP                          7
#define		RP1                          6
#define		RP0                          5
#define		NOT_TO                       4
#define		NOT_PD                       3
#define		Z                            2
#define		DC                           1
#define		C                            0

//;----- INTCON Bits -------------------------------------------------------

#define		GIE                          7
#define		PEIE                         6
#define		T0IE                         5
#define		INTE                         4
#define		GPIE                         3
#define		T0IF                         2
#define		INTF                         1
#define		GPIF                         0

//;----- PIR1 Bits --------------------------------------------

#define		EEIF                         7
#define		ADIF                         6
#define		CMIF                         3
#define		T1IF                         0
#define		TMR1IF                       0

//;----- T1CON Bits -------------------------------------------

#define		TMR1GE                       6
#define		T1CKPS1                      5
#define		T1CKPS0                      4
#define		T1OSCEN                      3
#define		NOT_T1SYNC                   2
#define		TMR1CS                       1
#define		TMR1ON                       0

//;----- COMCON Bits ------------------------------------------

#define		COUT                         6
#define		CINV                         4
#define		CIS                          3
#define		CM2                          2
#define		CM1                          1
#define		CM0                          0

//;----- ADCON0 Bits ------------------------------------------

#define		ADFM                         7
#define		VCFG                         6
#define		CHS1                         3
#define		CHS0                         2
#define		GO                           1
#define		NOT_DONE                     1
#define		GO_DONE                      1
#define		ADON                         0

//;----- OPTION Bits ------------------------------------------

#define		NOT_GPPU		     EQU     
#define		INTEDG                       6
#define		T0CS                         5
#define		T0SE                         4
#define		PSA                          3
#define		PS2                          2
#define		PS1                          1
#define		PS0                          0

//;----- PIE1 Bits --------------------------------------------

#define		EEIE                         7
#define		ADIE                         6
#define		CMIE                         3
#define		T1IE                         0
#define		TMR1IE                       0

//;----- PCON Bits --------------------------------------------

#define		NOT_POR                      1
#define		NOT_BOD                      0

//;----- OSCCAL Bits ------------------------------------------

#define		CAL5                         7
#define		CAL4                         6
#define		CAL3                         5
#define		CAL2                         4
#define		CAL1                         3
#define		CAL0                         2

//;----- VRCON Bits -------------------------------------------

#define		VREN                         7
#define		VRR                          5
#define		VR3                          3
#define		VR2                          2
#define		VR1                          1
#define		VR0                          0

//;----- EECON1 -----------------------------------------------

#define		WRERR                        3
#define		WREN                         2
#define		WR                           1
#define		RD                           0

//;----- ANSEL ------------------------------------------------

#define		ADCS2                        6
#define		ADCS1                        5
#define		ADCS0                        4
#define		ANS3                         3
#define		ANS2                         2
#define		ANS1                         1
#define		ANS0                         0

/*;==========================================================================
;
;       RAM Definition
;
;==========================================================================

        __MAXRAM H'FF'
        __BADRAM H'06'-H'09', H'0D', H'11'-H'18', H'1A'-H'1D', H'60'-H'7F'
        __BADRAM H'86'-H'89', H'8D', H'8F', H'91'-H'94', H'97'-H'98', H'E0'-H'FF'

;==========================================================================
;
;       Configuration Bits
;
;==========================================================================

_CPD_ON                      EQU     H'3EFF'
_CPD_OFF                     EQU     H'3FFF'
_CP_ON                       EQU     H'3F7F'
_CP_OFF                      EQU     H'3FFF'
_BODEN_ON                    EQU     H'3FFF'
_BODEN_OFF                   EQU     H'3FBF'
_MCLRE_ON                    EQU     H'3FFF'
_MCLRE_OFF                   EQU     H'3FDF'
_PWRTE_OFF                   EQU     H'3FFF'
_PWRTE_ON                    EQU     H'3FEF'
_WDT_ON                      EQU     H'3FFF'
_WDT_OFF                     EQU     H'3FF7'
_LP_OSC                      EQU     H'3FF8'
_XT_OSC                      EQU     H'3FF9'
_HS_OSC                      EQU     H'3FFA'
_EC_OSC                      EQU     H'3FFB'
_INTRC_OSC_NOCLKOUT          EQU     H'3FFC'
_INTRC_OSC_CLKOUT            EQU     H'3FFD'
_EXTRC_OSC_NOCLKOUT          EQU     H'3FFE'
_EXTRC_OSC_CLKOUT            EQU     H'3FFF'
*/
 #LIST
