////////////////////////////////////////////////////////////////////////////
////                             LCD.C                                  ////
////                 Driver for common LCD modules                      ////
////                                                                    ////
////  lcd_init()   Must be called before any other function.            ////
////                                                                    ////
////  lcd_putc(c)  Will display c on the next position of the LCD.      ////
////                     The following have special meaning:            ////
////                      \f  Clear display                             ////
////                      \n  Go to start of second line                ////
////                      \b  Move back one position                    ////
////                                                                    ////
////  lcd_gotoxy(x,y) Set write position on LCD (upper left is 1,1)     ////
////                                                                    ////
////  lcd_getc(x,y)   Returns character at position x,y on LCD          ////
////                                                                    ////
////////////////////////////////////////////////////////////////////////////
////        (C) Copyright 1996,1997 Custom Computer Services            ////
//// This source code may only be used by licensed users of the CCS C   ////
//// compiler.  This source code may only be distributed to other       ////
//// licensed users of the CCS C compiler.  No other use, reproduction  ////
//// or distribution is permitted without written permission.           ////
//// Derivative programs created using this software in object code     ////
//// form are not restricted in any way.                                ////
////////////////////////////////////////////////////////////////////////////
// Krzysztof Pawsiuk (2002)- Procedura obslugiwyswietlacza LCD zostala ////
// stworzona na bazie procedury udostepnianej wraz z kompilatorem.		////
// Procedura zostala w znacznym stopniu przebudowana, najwazniejsza 	////
// zmiana umozliwia dowolne przypisanie pinow sterujacych wyswietlaczem ////
// poszczegolne linie danych lub sterujace moga pochodzic z roznych     ////
// portow.																////
////////////////////////////////////////////////////////////////////////////
#ifndef lcd
   //#define   lcd_rw        portc_2
   //#define   lcd_tris_rw   trisc_2
   #define   lcd_en        portc_3
   #define   lcd_tris_en   trisc_3
   #define   lcd_rs        portc_1
   #define   lcd_tris_rs   trisc_1
   #define   lcd_d7        portc_7
   #define   lcd_tris_d7   trisc_7
   #define   lcd_d6        portc_6
   #define   lcd_tris_d6   trisc_6
   #define   lcd_d5        portc_5
   #define   lcd_tris_d5   trisc_5
   #define   lcd_d4        portc_4
   #define   lcd_tris_d4   trisc_4
#endif

#define  0
#define  1
#define  2
#define  3
#define  4
#define lcd_type 2           // 0=5x7, 1=5x10, 2=2 lines
#define lcd_line_two 0x40    // LCD RAM address for the second line


byte CONST LCD_INIT_STRING[4] = {0x20 | (lcd_type << 2), 0xc, 1, 6};
                             // These bytes need to be sent to the LCD
                             // to start it up.
//deklaracja znakow 0=,1=,2=,3=,4=,5=
byte CONST LCD_[8] = {
                        //0x0C,0x04,0x06,0x0c,0x04,0x04,0x0E,0x00,         	//
                        //0x02,0x04,0x0E,0x11,0x11,0x11,0x0E,0x00,      	//
                        0x02,0x04,0x0E,0x10,0x0E,0x01,0x1E,0x00};      		//
                        //0x02,0x04,0x0E,0x10,0x10,0x11,0x0E,0x00,     		//
                        //0x00,0x04,0x1F,0x02,0x04,0x08,0x1F,0x00,     		//
                        //0x00,0x00,0x0E,0x11,0x1F,0x10,0x0E,0x02,     	 	//
                        //0x00,0x00,0x0E,0x01,0x0F,0x11,0x0F,0x02};	  		//


#ifdef lcd_rw
byte lcd_read_byte() {
      byte low,high;
      lcd_tris_d7=1;lcd_tris_d6=1;lcd_tris_d5=1;lcd_tris_d4=1; //piny danych jako wejscia
      lcd_rw = 1;
      delay_cycles(1);
      lcd_en = 1;
      delay_cycles(1);
      high=0;              					//odzczytuje stany wszystkich wejsc danych
      if(lcd_d4) high+=1;          			//wynik jest w high, aby odczytac 4 bity trzeba dodawac
      if(lcd_d5)           					//poszczegolne bity wedlog ich wagi, dlatego, ze kazdy bit
         high+=2;          					//moze byc z innego portu
      if(lcd_d6) high+=4;
      if(lcd_d7) high+=8;
      lcd_en = 0;
      delay_cycles(1);
      lcd_en = 1;
      delay_us(1);
      low=0;
      if(lcd_d4) low+=1;   					//odczytaj druga tetrade i zpisz wynik w low
      if(lcd_d5) low+=2;
      if(lcd_d6) low+=4;
      if(lcd_d7) low+=8;
      lcd_en = 0;
      lcd_tris_d7=0;lcd_tris_d6=0;lcd_tris_d5=0;lcd_tris_d4=0; //piny danych jako wyjscia
      return( (high<<4) | low);
}
#endif
//  wysyla mlodsza tetrade bajtu n do wyswietlacza
void lcd_send_nibble( byte n ) {
      lcd_d4=bit_test(n,0);
      lcd_d5=bit_test(n,1);
      lcd_d6=bit_test(n,2);
      lcd_d7=bit_test(n,3);
      delay_cycles(1);
      lcd_en = 1;
      delay_us(2);
      lcd_en = 0;
}
////////////////////////////////////////////////////////////////////////////////////////

void lcd_send_byte( byte address, byte n ) {

      lcd_rs = 0;
#ifdef lcd_rw
      while ( bit_test(lcd_read_byte(),7) ) ;//czekaj az wyswietlacz bedzie gotowy
 #else
      delay_us(40);     					//jesli busy nie jest odczytywany z lcd to czekaj
#endif                  					// na wykonanie instrukcji 40us

      lcd_rs = address;
      delay_cycles(1);
#ifdef lcd_rw                 				//jesli jest urzywany pin RW
      lcd_rw = 0;
#endif
      delay_cycles(1);
      lcd_en = 0;
      lcd_send_nibble(n >> 4);
      lcd_send_nibble(n & 0xf);
}
///////////////////////////////////////////////////////////////////////////////////////////////
//inicjalizacja wyswietlacza - dziala
//  lcd_init();
/////////////////////////////////////////////////////////////////////////////////////////////
void lcd_init() {
    byte i;
    lcd_d7=0;lcd_d6=0;lcd_d5=0;lcd_d4=0;                     //piny danych jako wyjscia
    lcd_tris_d7=0;lcd_tris_d6=0;lcd_tris_d5=0;lcd_tris_d4=0; //piny danych jako wyjscia
    lcd_rs = 0;
    lcd_tris_rs=0;                                           //piny seterujace=0
    lcd_en = 0;
    lcd_tris_en=0;
//jesli jest wykozystywany pin RW to zrob to
#ifdef lcd_rw
    lcd_rw = 0;
    lcd_tris_rw=0;                                          //piny sterujace jako wyjscia
#endif
//-----------------------------------------------------------------
    delay_ms(15);                                           //czekaj na start lcd
    for(i=1;i<=3;++i) {
       lcd_send_nibble(3);
       delay_ms(5);
    }
   lcd_send_nibble(2);
   lcd_send_byte(0,0x20 | (lcd_type << 2));
   lcd_send_byte(0,0xc);
   lcd_send_byte(0,1);           							//lcd wyswietlacz lcd
   delay_ms(2);
   lcd_send_byte(0,6);
}
//////////////////////////////////////////////////////////////////////////////////////////////

// ustawia kursor na pozycji xy
void lcd_gotoxy( byte y, byte x) {
   byte address;

   if(y!=1)
     address=lcd_line_two;
   else
     address=0;
   address+=x-1;
   lcd_send_byte(0,0x80|address);
}
//******************************************************
void lcd_znaki()
{
int adres;int licz;
adres=0x40;
      lcd_send_byte(0,adres);  								//ustawienie adresu pamieci lcd na zero
      for(licz=0;licz<8;licz++) {
         lcd_send_byte(0,adres);  							//ustawienie adresu pamieci lcd na zero
         lcd_send_byte(1,lcd_[licz]);
         adres++;
         }
  }

//---------------------------------------------------------------------------------
//    wyswietla znaki na wyswietlaczu
void lcd_putc(char f) {
   switch (f) {
     case '\r'   : lcd_send_byte(0,1);
                   delay_ms(2);
                  break;
     case '\v'	 : lcd_send_byte(0,0b00001110);break;	// wlacza kursor
	 case '\q'   :lcd_send_byte(0,0b00001100);break;	//wylacza kursor
     case '\n'   : lcd_gotoxy(2,1);        break;
     case '\b'   : lcd_send_byte(0,0x10);  break;
     default     : lcd_send_byte(1,f);     break;
   }
}


//   odczytuje bajt z wyswietlacza z pozycji xy
#ifdef lcd_rw
char lcd_getc( byte y, byte x) {
   char value;

    lcd_gotoxy(y,x);
    lcd_rs=1;
    value = lcd_read_byte();
    lcd_rs=0;
    return(value);
}
#endif


